==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ta/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'பெரும்பங்கு சொத்துக்களை நீக்குவதை உறுதிப்படுத்தவும்',
  'bulk_delete_help'	=> 'கீழே மொத்த நீக்குவதற்கான சொத்துக்களை மதிப்பாய்வு செய்யவும். நீக்கப்பட்டவுடன், இந்த சொத்துகள் மீட்டமைக்கப்படலாம், ஆனால் அவை தற்போது எந்த பயனர்களையும் தற்போது ஒதுக்கப்படும்.',
  'bulk_delete_warn'	=> 'நீங்கள் நீக்குவது: asset_count சொத்துகள்.',
	'bulk_update'		=> 'மொத்த புதுப்பித்தல் சொத்துகள்',
	'bulk_update_help'	=> 'இந்த படிவம் ஒரே நேரத்தில் பல சொத்துக்களை புதுப்பிக்க உதவுகிறது. நீங்கள் மாற்ற வேண்டிய துறைகள் மட்டுமே நிரப்பவும். காலியாக உள்ள எந்த புலமும் மாறாமல் இருக்கும்.',
	'bulk_update_warn'	=> 'சொத்துக்களின் திருத்தங்களை நீங்கள் திருத்திக் கொள்ள உள்ளீர்கள்: asset_count assets.',
    'checkedout_to'		=> 'அவுட் சரிபார்க்கப்பட்டது',
    'checkout_date'		=> 'புதுப்பிப்பு தேதி',
    'checkin_date'		=> 'சரி தேதி',
    'checkout_to'		=> 'புதுப்பித்தல்',
    'cost'				=> 'கொள்முதல் செலவு',
    'create'			=> 'சொத்து உருவாக்கவும்',
    'date'				=> 'கொள்முதல் தேதி',
    'depreciation'	    => 'தேய்மானம்',
    'depreciates_on'	=> 'நிக்காது',
    'default_location'	=> 'இயல்புநிலை இருப்பிடம்',
    'eol_date'			=> 'EOL தேதி',
    'eol_rate'			=> 'EOL விகிதம்',
    'expected_checkin'  => 'எதிர்பார்த்த செக்கின் தேதி',
    'expires'			=> 'காலாவதியாகிறது',
    'fully_depreciated'	=> 'முற்றிலும் குறைத்து மதிப்பிடப்பட்டுள்ளது',
    'help_checkout'		=> 'நீங்கள் உடனடியாக இந்த சொத்தை ஒதுக்க விரும்பினால், மேலேயுள்ள நிலை பட்டியலில் இருந்து "வரிசைப்படுத்துவதற்குத் தயார்" என்பதைத் தேர்ந்தெடுக்கவும்.',
    'mac_address'		=> 'Mac முகவரி',
    'manufacturer'		=> 'உற்பத்தியாளர்',
    'model'				=> 'மாதிரி',
    'months'			=> 'மாதங்கள்',
    'name'				=> 'சொத்து பெயர்',
    'notes'				=> 'குறிப்புக்கள்',
    'order'				=> 'ஆர்டர் எண்',
    'qr'				=> 'க்யு ஆர் குறியீடு',
    'requestable'		=> 'பயனர்கள் இந்த சொத்தை கோரலாம்',
    'select_statustype'	=> 'நிலை வகை தேர்ந்தெடுக்கவும்',
    'serial'			=> 'சீரியல்',
    'status'			=> 'நிலைமை',
    'tag'				=> 'சொத்து டேக்',
    'update'			=> 'சொத்து புதுப்பிப்பு',
    'warranty'			=> 'உத்தரவாதத்தை',
		'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'ஆண்டுகள்',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ta/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'பெரும்பங்கு சொத்துக்களை நீக்குவதை உறுதிப்படுத்தவும்',
  'bulk_delete_help'	=> 'கீழே மொத்த நீக்குவதற்கான சொத்துக்களை மதிப்பாய்வு செய்யவும். நீக்கப்பட்டவுடன், இந்த சொத்துகள் மீட்டமைக்கப்படலாம், ஆனால் அவை தற்போது எந்த பயனர்களையும் தற்போது ஒதுக்கப்படும்.',
  'bulk_delete_warn'	=> 'நீங்கள் நீக்குவது: asset_count சொத்துகள்.',
    'bulk_update'		=> 'மொத்த புதுப்பித்தல் சொத்துகள்',
    'bulk_update_help'	=> 'இந்த படிவம் ஒரே நேரத்தில் பல சொத்துக்களை புதுப்பிக்க உதவுகிறது. நீங்கள் மாற்ற வேண்டிய துறைகள் மட்டுமே நிரப்பவும். காலியாக உள்ள எந்த புலமும் மாறாமல் இருக்கும்.',
    'bulk_update_warn'	=> 'சொத்துக்களின் திருத்தங்களை நீங்கள் திருத்திக் கொள்ள உள்ளீர்கள்: asset_count assets.',
    'checkedout_to'		=> 'அவுட் சரிபார்க்கப்பட்டது',
    'checkout_date'		=> 'புதுப்பிப்பு தேதி',
    'checkin_date'		=> 'சரி தேதி',
    'checkout_to'		=> 'புதுப்பித்தல்',
    'cost'				=> 'கொள்முதல் செலவு',
    'create'			=> 'சொத்து உருவாக்கவும்',
    'date'				=> 'கொள்முதல் தேதி',
    'depreciation'	    => 'தேய்மானம்',
    'depreciates_on'	=> 'நிக்காது',
    'default_location'	=> 'இயல்புநிலை இருப்பிடம்',
    'eol_date'			=> 'EOL தேதி',
    'eol_rate'			=> 'EOL விகிதம்',
    'expected_checkin'  => 'எதிர்பார்த்த செக்கின் தேதி',
    'expires'			=> 'காலாவதியாகிறது',
    'fully_depreciated'	=> 'முற்றிலும் குறைத்து மதிப்பிடப்பட்டுள்ளது',
    'help_checkout'		=> 'நீங்கள் உடனடியாக இந்த சொத்தை ஒதுக்க விரும்பினால், மேலேயுள்ள நிலை பட்டியலில் இருந்து "வரிசைப்படுத்துவதற்குத் தயார்" என்பதைத் தேர்ந்தெடுக்கவும்.',
    'mac_address'		=> 'Mac முகவரி',
    'manufacturer'		=> 'உற்பத்தியாளர்',
    'model'				=> 'மாதிரி',
    'months'			=> 'மாதங்கள்',
    'name'				=> 'சொத்து பெயர்',
    'notes'				=> 'குறிப்புக்கள்',
    'order'				=> 'ஆர்டர் எண்',
    'qr'				=> 'க்யு ஆர் குறியீடு',
    'requestable'		=> 'பயனர்கள் இந்த சொத்தை கோரலாம்',
    'select_statustype'	=> 'நிலை வகை தேர்ந்தெடுக்கவும்',
    'serial'			=> 'சீரியல்',
    'status'			=> 'நிலைமை',
    'tag'				=> 'சொத்து டேக்',
    'update'			=> 'சொத்து புதுப்பிப்பு',
    'warranty'			=> 'உத்தரவாதத்தை',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'ஆண்டுகள்',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
